[PATCH] scsi: ufs: changing authors e-mail

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



Although I am leaving Synopsys, I would like to keep working with the
linux kernel community and help in what you might find useful. For that
I am sending this patch to change my contact e-mail. 

Signed-off-by: Joao Pinto <jpinto@xxxxxxxxxxxx>
---
 drivers/scsi/ufs/tc-dwc-g210-pci.c    | 4 ++--
 drivers/scsi/ufs/tc-dwc-g210-pltfrm.c | 4 ++--
 drivers/scsi/ufs/tc-dwc-g210.c        | 4 ++--
 drivers/scsi/ufs/tc-dwc-g210.h        | 2 +-
 drivers/scsi/ufs/ufshcd-dwc.c         | 4 ++--
 drivers/scsi/ufs/ufshcd-dwc.h         | 2 +-
 drivers/scsi/ufs/ufshci-dwc.h         | 2 +-
 7 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/drivers/scsi/ufs/tc-dwc-g210.h b/drivers/scsi/ufs/tc-dwc-g210.h
index fb177db..3ec4373 100644
--- a/drivers/scsi/ufs/tc-dwc-g210.h
+++ b/drivers/scsi/ufs/tc-dwc-g210.h
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
diff --git a/drivers/scsi/ufs/ufshcd-dwc.h b/drivers/scsi/ufs/ufshcd-dwc.h
index c8be295..0bbad1b 100644
--- a/drivers/scsi/ufs/ufshcd-dwc.h
+++ b/drivers/scsi/ufs/ufshcd-dwc.h
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
diff --git a/drivers/scsi/ufs/ufshci-dwc.h b/drivers/scsi/ufs/ufshci-dwc.h
index ca341fe..1b31330 100644
--- a/drivers/scsi/ufs/ufshci-dwc.h
+++ b/drivers/scsi/ufs/ufshci-dwc.h
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
diff --git a/drivers/scsi/ufs/tc-dwc-g210-pci.c b/drivers/scsi/ufs/tc-dwc-g210-pci.c
index c09a0fe..13b9e6c 100644
--- a/drivers/scsi/ufs/tc-dwc-g210-pci.c
+++ b/drivers/scsi/ufs/tc-dwc-g210-pci.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
  * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -176,6 +176,6 @@ static void tc_dwc_g210_pci_remove(struct pci_dev *pdev)
 
 module_pci_driver(tc_dwc_g210_pci_driver);
 
-MODULE_AUTHOR("Joao Pinto <Joao.Pinto@xxxxxxxxxxxx>");
+MODULE_AUTHOR("Joao Pinto <jpmpinto@xxxxxxxxx>");
 MODULE_DESCRIPTION("Synopsys Test Chip G210 PCI glue driver");
 MODULE_LICENSE("Dual BSD/GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
diff --git a/drivers/scsi/ufs/tc-dwc-g210-pltfrm.c b/drivers/scsi/ufs/tc-dwc-g210-pltfrm.c
index 2d3f527..89166a9 100644
--- a/drivers/scsi/ufs/tc-dwc-g210-pltfrm.c
+++ b/drivers/scsi/ufs/tc-dwc-g210-pltfrm.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
  * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -109,5 +109,5 @@ static int tc_dwc_g210_pltfm_remove(struct platform_device *pdev)
 
 MODULE_ALIAS("platform:tc-dwc-g210-pltfm");
 MODULE_DESCRIPTION("Synopsys Test Chip G210 platform glue driver");
-MODULE_AUTHOR("Joao Pinto <Joao.Pinto@xxxxxxxxxxxx>");
+MODULE_AUTHOR("Joao Pinto <jpmpinto@xxxxxxxxx>");
 MODULE_LICENSE("Dual BSD/GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
diff --git a/drivers/scsi/ufs/tc-dwc-g210.c b/drivers/scsi/ufs/tc-dwc-g210.c
index dc03e47..aeff7ff 100644
--- a/drivers/scsi/ufs/tc-dwc-g210.c
+++ b/drivers/scsi/ufs/tc-dwc-g210.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
  * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -315,6 +315,6 @@ int tc_dwc_g210_config_20_bit(struct ufs_hba *hba)
 }
 EXPORT_SYMBOL(tc_dwc_g210_config_20_bit);
 
-MODULE_AUTHOR("Joao Pinto <Joao.Pinto@xxxxxxxxxxxx>");
+MODULE_AUTHOR("Joao Pinto <jpmpinto@xxxxxxxxx>");
 MODULE_DESCRIPTION("Synopsys G210 Test Chip driver");
 MODULE_LICENSE("Dual BSD/GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
diff --git a/drivers/scsi/ufs/ufshcd-dwc.c b/drivers/scsi/ufs/ufshcd-dwc.c
index 5fd16c7..28bd3a3 100644
--- a/drivers/scsi/ufs/ufshcd-dwc.c
+++ b/drivers/scsi/ufs/ufshcd-dwc.c
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
  * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2 as
@@ -149,6 +149,6 @@ int ufshcd_dwc_link_startup_notify(struct ufs_hba *hba,
 }
 EXPORT_SYMBOL(ufshcd_dwc_link_startup_notify);
 
-MODULE_AUTHOR("Joao Pinto <Joao.Pinto@xxxxxxxxxxxx>");
+MODULE_AUTHOR("Joao Pinto <jpmpinto@xxxxxxxxx>");
 MODULE_DESCRIPTION("UFS Host driver for Synopsys Designware Core");
 MODULE_LICENSE("Dual BSD/GPL");
@@ -3,7 +3,7 @@
  * Copyright (C) 2015-2016 Synopsys, Inc. (www.synopsys.com)
  *
- * Authors: Joao Pinto <jpinto@xxxxxxxxxxxx>
+ * Authors: Joao Pinto <jpmpinto@xxxxxxxxx>
  *
  * This program is free software; you can redistribute it and/or modify
-- 
1.8.1.5

--
To unsubscribe from this list: send the line "unsubscribe linux-scsi" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html



[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
[Index of Archives]     [SCSI Target Devel]     [Linux SCSI Target Infrastructure]     [Kernel Newbies]     [IDE]     [Security]     [Git]     [Netfilter]     [Bugtraq]     [Yosemite News]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux ATA RAID]     [Linux IIO]     [Samba]     [Device Mapper]
  Powered by Linux